%define lib_name_orig libalsa
%define major 2
%define lib_name %mklibname alsa %{major}
%define beta 0
%if %{beta}
%define fname alsa-lib-%{version}%{beta}
%else
%define fname alsa-lib-%{version}
%endif

Summary:	Advanced Linux Sound Architecture (ALSA) library
Name:		libalsa2
Version:	1.1.3
%if %{beta}
Release:	%mkrel 0.%{beta}.6
%else
Release:	%mkrel 1
%endif
Source0:	ftp://ftp.alsa-project.org/pub/lib/%{fname}.tar.bz2
Source1:	README.soundprofiles
License:	LGPLv2+
Epoch:		2
Url:		http://www.alsa-project.org/
Group:		Sound/Utilities
BuildRequires:	doxygen 
BuildRequires:	pkgconfig(python)
# keep the list below in sync with the lib_name package
Provides:	alsa-lib = %{epoch}:%{version}-%{release}
Provides:	%{lib_name_orig} = %{epoch}:%{version}-%{release}
Obsoletes:	alsa-lib < %{epoch}:%{version}-%{release}
Obsoletes:	%{lib_name_orig} < %{epoch}:%{version}-%{release}
Requires:	%{lib_name_orig}-data

%description
Advanced Linux Sound Architecture (ALSA) is a modularized architecture which
supports quite a large range of ISA and PCI cards.
It's fully compatible with old OSS drivers (either OSS/Lite, OSS/commercial).
To use the features of alsa, one can either use:
- the old OSS api
- the new ALSA api that provides many enhanced features.

Using the ALSA api requires to use the ALSA library.

%if "%{_lib}" != "lib"
%package -n %{lib_name}
Summary:	Advanced Linux Sound Architecture (ALSA) library
Group:		Sound/Utilities
Provides:	alsa-lib = %{epoch}:%{version}-%{release}
Provides:	%{lib_name_orig} = %{epoch}:%{version}-%{release}
Obsoletes:	alsa-lib < %{epoch}:%{version}-%{release}
Obsoletes:	%{lib_name_orig} < %{epoch}:%{version}-%{release}
Requires:	%{lib_name_orig}-data
Recommends:	%{_lib}alsa-plugins

%description -n %{lib_name}
Advanced Linux Sound Architecture (ALSA) is a modularized architecture which
supports quite a large range of ISA and PCI cards.
It's fully compatible with old OSS drivers (either OSS/Lite, OSS/commercial).
To use the features of alsa, one can either use:
- the old OSS api
- the new ALSA api that provides many enhanced features.

Using the ALSA api requires to use the ALSA library.
%endif

%define alt_name soundprofile
%define alt_priority 10

%package -n %{lib_name_orig}-data
Summary:    Config files for Advanced Linux Sound Architecture (ALSA)
Group:      Sound/Utilities
BuildArch:  noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description -n %{lib_name_orig}-data
Advanced Linux Sound Architecture (ALSA) is a modularized architecture which
supports quite a large range of ISA and PCI cards.
It's fully compatible with old OSS drivers (either OSS/Lite, OSS/commercial).
To use the features of alsa, one can either use:
- the old OSS api
- the new ALSA api that provides many enhanced features.

This package contains config files by ALSA applications.

%post -n %{lib_name_orig}-data
%{_sbindir}/update-alternatives \
  --install %{_sysconfdir}/sound/profiles/current %{alt_name} %{_sysconfdir}/sound/profiles/alsa %{alt_priority}

%postun -n %{lib_name_orig}-data
if [ ! -f %{_sysconfdir}/sound/profiles/alsa/profile.conf ]; then
  /usr/sbin/update-alternatives --remove %{alt_name} %{_sysconfdir}/sound/profiles/alsa
fi

%package -n %{lib_name}-devel
Summary:    Development files for Advanced Linux Sound Architecture (ALSA)
Group:      Development/C
Requires:   %{lib_name} = %{epoch}:%{version}
Provides:   libalsa1-devel = %{epoch}:%{version}-%{release}
Provides:   alsa-lib-devel = %{epoch}:%{version}-%{release}
Provides:   %{lib_name_orig}-devel = %{epoch}:%{version}-%{release}
Obsoletes:   libalsa1-devel < %{epoch}:%{version}-%{release}
Obsoletes:   alsa-lib-devel < %{epoch}:%{version}-%{release}
Obsoletes:   %{lib_name_orig}-devel < %{epoch}:%{version}-%{release}
# (cg) As of 1.0.25 you cannot build static and shared together...
# so lets just obsolete the static-devel
Obsoletes:  %{lib_name}-static-devel < 2:1.0.25

%description -n %{lib_name}-devel
Advanced Linux Sound Architecture (ALSA) is a modularized architecture which
supports quite a large range of ISA and PCI cards.
It's fully compatible with old OSS drivers (either OSS/Lite, OSS/commercial).
To use the features of alsa, one can either use:
- the old OSS api
- the new ALSA api that provides many enhanced features.

This package contains files needed in order to develop an application
that made use of ALSA.

%package docs
Summary:    Documentation for Advanced Linux Sound Architecture (ALSA)
Group:      Documentation
Requires:   alsa-lib = %{epoch}:%{version}
BuildArch:  noarch

%description docs
Advanced Linux Sound Architecture (ALSA) is a modularized architecture which
supports quite a large range of ISA and PCI cards.
It's fully compatible with old OSS drivers (either OSS/Lite, OSS/commercial).
To use the features of alsa, one can either use:
- the old OSS api
- the new ALSA api that provides many enhanced features.

The Advanced Linux Sound Architecture comes with a kernel API and library API.
This document describes the library API and how it interfaces with the kernel
API. Application programmers should use the library API rather than kernel API.

The Library offers 100% of the functionally of the kernel API, but add next
major improvements in usability, making the application code simpler and better
looking.

This package contains the documentation that describe tha ALSA lib API.

%prep
%setup -q -n %{fname}
%autopatch -p1

%build
autoreconf -if
%configure2_5x --enable-shared --enable-python
# Force definition of -DPIC so that VERSIONED_SYMBOLS are used
# FIXME: alsa people should not depend on PIC to determine a DSO build...
perl -pi -e 's,(^pic_flag=.+)(-fPIC),\1-DPIC \2,' libtool

%make
%make -C doc doc

%install
%makeinstall_std

# (cg) For sound profile support
mkdir -p %{buildroot}%{_sysconfdir}/sound/profiles/alsa
echo "SOUNDPROFILE=alsa" >%{buildroot}%{_sysconfdir}/sound/profiles/alsa/profile.conf
echo "# This file is left blank to allow alsa to default to dmix" >%{buildroot}%{_sysconfdir}/sound/profiles/alsa/alsa-default.conf
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sound/profiles/README
ln -s %{_sysconfdir}/sound/profiles/current/alsa-default.conf %{buildroot}%{_datadir}/alsa/alsa.conf.d/99-default.conf

# (blino) not very useful, Debian also dropped it (Debian bugs #290735, #285320)
rm -f %{buildroot}%{_bindir}/aserver

rm -f %{buildroot}%{_libdir}/alsa-lib/smixer/*.la
rm -f %{buildroot}%{_libdir}/*.la

%files -n %{lib_name_orig}-data
%doc COPYING
%dir %{_sysconfdir}/sound/profiles
%dir %{_sysconfdir}/sound/profiles/alsa
%{_sysconfdir}/sound/profiles/README
%{_sysconfdir}/sound/profiles/alsa/profile.conf
%{_sysconfdir}/sound/profiles/alsa/alsa-default.conf
%dir %{_datadir}/alsa/
%dir %{_datadir}/alsa/alsa.conf.d/
%dir %{_datadir}/alsa/cards/
%dir %{_datadir}/alsa/pcm/
%{_datadir}/alsa/alsa.conf.d/*
%{_datadir}/alsa/cards/*
%{_datadir}/alsa/pcm/*
%{_datadir}/alsa/alsa.conf
%{_datadir}/alsa/smixer.conf
%{_datadir}/alsa/sndo-mixer.alisp
%{_datadir}/alsa/topology
%{_datadir}/alsa/ucm

%files -n %{lib_name}
%doc COPYING 
%{_libdir}/*.so.%{major}*
%dir %{_libdir}/alsa-lib
%dir %{_libdir}/alsa-lib/smixer/
%{_libdir}/alsa-lib/smixer/*

%files docs
%doc COPYING doc/doxygen/html/* doc/asoundrc.txt

%files -n %{lib_name}-devel
%doc COPYING
%dir %{_includedir}/alsa/
%{_includedir}/alsa/*
%{_includedir}/sys/asoundlib.h
%{_datadir}/aclocal/alsa.m4
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Thu Dec 22 2016 luigiwalser <luigiwalser> 2:1.1.3-1.mga6
+ Revision: 1076500
- 1.1.3

* Thu Aug 11 2016 luigiwalser <luigiwalser> 2:1.1.2-1.mga6
+ Revision: 1045661
- 1.1.2

* Fri Apr 01 2016 tv <tv> 2:1.1.1-1.mga6
+ Revision: 997364
- new release

* Sat Mar 05 2016 luigiwalser <luigiwalser> 2:1.1.0-3.mga6
+ Revision: 985907
- remove invalid requires

* Sat Mar 05 2016 blino <blino> 2:1.1.0-2.mga6
+ Revision: 985875
- rebuild for armv5tl (also missed in first Mga6 mass rebuild)

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

  + tv <tv>
    - make data subpackage noarch
    - switch to pkgconfig() BRs

* Mon Nov 09 2015 tv <tv> 2:1.1.0-1.mga6
+ Revision: 899972
- new release

* Tue Jun 23 2015 tv <tv> 2:1.0.29-1.mga6
+ Revision: 840244
- new release
- s/uggests:/Recommends:/

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

* Wed Jun 18 2014 tv <tv> 2:1.0.28-1.mga5
+ Revision: 637887
- new release

* Mon Jan 06 2014 tv <tv> 2:1.0.27.2-3.mga4
+ Revision: 565169
- do not suggests libalsa-plugins anymore (debloat, mga#8455)

* Mon Dec 16 2013 blino <blino> 2:1.0.27.2-2.mga4
+ Revision: 557537
- alsa-plugins should be suggested for x86_64 too

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Tue Jul 09 2013 fwang <fwang> 2:1.0.27.2-1.mga4
+ Revision: 451599
- new version 1.0.27.2

* Fri May 24 2013 tv <tv> 2:1.0.27.1-1.mga4
+ Revision: 426504
- adjust file list
- drop merged patches
- new release

* Wed Jan 30 2013 colin <colin> 2:1.0.26-7.mga3
+ Revision: 393540
- Add an upstream fix for some UCM related issue.

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + dmorgan <dmorgan>
    - Add missing include in pcm.h

* Fri Jan 11 2013 cjw <cjw> 2:1.0.26-6.mga3
+ Revision: 347559
- patch2: fix building against alsalib with new glibc

* Sat Jan 05 2013 cjw <cjw> 2:1.0.26-5.mga3
+ Revision: 339240
- patch1: fix build with automake 1.13

* Tue Oct 16 2012 malo <malo> 2:1.0.26-4.mga3
+ Revision: 307327
- update RPM group for Documentation

* Mon Oct 08 2012 blino <blino> 2:1.0.26-3.mga3
+ Revision: 303551
- use Sound/Utilities rpm group
- drop aserver from devel package, not very useful and breaks bi-arch install of devel packages

* Tue Sep 11 2012 fwang <fwang> 2:1.0.26-2.mga3
+ Revision: 292166
- requires virtual name

* Fri Sep 07 2012 fwang <fwang> 2:1.0.26-1.mga3
+ Revision: 289092
- New version 1.0.26
- drop upstream patches

* Sat Apr 07 2012 fwang <fwang> 2:1.0.25-3.mga2
+ Revision: 229476
- cleanup provides and obsoletes

* Thu Mar 15 2012 colin <colin> 2:1.0.25-2.mga2
+ Revision: 223548
- Add upstream patches (cosmetic+penum over-application fix)
- Remove old patch files

* Wed Jan 25 2012 colin <colin> 2:1.0.25-1.mga2
+ Revision: 201522
- New version: 1.0.25
- Dropped static library (upstream no longer support shared+static builds)

* Mon Jan 23 2012 dmorgan <dmorgan> 2:1.0.24.1-7.mga2
+ Revision: 200149
- Own %%_libdir/alsa-lib

  + colin <colin>
    - Revert previous change (the link is correct - something else is wrong). mga#2966

  + eatdirt <eatdirt>
    - Fix wrong link to alsa-default.conf (BUG 2966)

* Mon Sep 19 2011 colin <colin> 2:1.0.24.1-6.mga2
+ Revision: 145632
- Fix sound on the non-PA profile.

* Sat Sep 17 2011 colin <colin> 2:1.0.24.1-5.mga2
+ Revision: 144501
- Use an upstream submitted patch for more flexible config without patching

* Thu Sep 15 2011 fwang <fwang> 2:1.0.24.1-4.mga2
+ Revision: 143769
- drop .la files

* Tue Apr 26 2011 colin <colin> 2:1.0.24.1-3.mga1
+ Revision: 91704
- Various upstream cherry-picks for increased compatibility (esp. with PA)

* Thu Mar 24 2011 boklm <boklm> 2:1.0.24.1-2.mga1
+ Revision: 76162
- rebuild for bug #497

* Tue Mar 08 2011 ahmad <ahmad> 2:1.0.24.1-1.mga1
+ Revision: 66340
- update to 1.0.24.1
- drop the patches that were merged upstream
- don't run autoreconf, not needed AFAICS
- fix license

* Mon Jan 17 2011 blino <blino> 2:1.0.23-9.mga1
+ Revision: 21221
- rebuild with new python

* Sun Jan 09 2011 ahmad <ahmad> 2:1.0.23-8.mga1
+ Revision: 1574
- imported package libalsa2

